Processor.App.Extractor.dummy\_extractor.Extractor.extract\_soup
================================================================

.. currentmodule:: Processor.App.Extractor.dummy_extractor

.. automethod:: Extractor.extract_soup